'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ufunc = require('ufunc');

var _ufunc2 = _interopRequireDefault(_ufunc);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pos = function pos(element) {
  return {
    top: element.offsetTop,
    left: element.offsetLeft
  };
};

var dim = function dim(element) {
  return {
    height: element.offsetHeight,
    width: element.offsetWidth
  };
};

var offset = function offset(opts) {
  var target = opts.target;
  var element = opts.element;
  var flip = opts.flip;
  var boundary = opts.boundary;

  var boundaryDim = undefined;

  if (boundary) {
    boundaryDim = dim(boundary);
  } else {
    boundaryDim = {
      width: Math.max(document.documentElement.clientWidth, window.innerWidth || 0),
      height: Math.max(document.documentElement.clientHeight, window.innerHeight || 0)
    };
  }

  var targetDetails = {
    pos: pos(target),
    dim: dim(target),
    boundary: target.getBoundingClientRect()
  };

  var elementDetails = {
    pos: pos(element),
    dim: dim(element),
    boundary: element.getBoundingClientRect()
  };

  var horFlip = _ufunc2.default.either(function () {
    return targetDetails.pos.top + targetDetails.dim.height;
  }, function () {
    return targetDetails.pos.top - elementDetails.dim.height;
  });

  var lrVerFlip = _ufunc2.default.either(function () {
    return targetDetails.pos.left + targetDetails.dim.width;
  }, function () {
    return targetDetails.pos.left - elementDetails.dim.width;
  });

  var tbVerLeft = targetDetails.pos.left;
  var tbVerRight = targetDetails.pos.left - (elementDetails.dim.width - targetDetails.dim.width);

  var top = undefined;
  var bottom = undefined;
  var lrHorLeft = undefined;
  var lrHorRight = undefined;

  if (flip) {
    top = horFlip(targetDetails.boundary.top - elementDetails.dim.height < 0);
    bottom = horFlip(targetDetails.boundary.top + elementDetails.dim.height + targetDetails.dim.height < boundaryDim.height);
    lrHorLeft = lrVerFlip(targetDetails.boundary.left - elementDetails.dim.width < 0);
    lrHorRight = lrVerFlip(targetDetails.boundary.left + elementDetails.dim.width + targetDetails.dim.width < boundaryDim.width);
  } else {
    top = horFlip(false);
    bottom = horFlip(true);
    lrHorLeft = lrVerFlip(false);
    lrHorRight = lrVerFlip(true);
  }

  var horCenter = targetDetails.pos.left - (elementDetails.dim.width - targetDetails.dim.width) / 2;
  var verCenter = bottom - (elementDetails.dim.height + targetDetails.dim.height) / 2;

  var position = {
    'bottom-left': { top: bottom, left: tbVerLeft },
    'bottom-center': { top: bottom, left: horCenter },
    'bottom-right': { top: bottom, left: tbVerRight },

    'top-left': { top: top, left: tbVerLeft },
    'top-center': { top: top, left: horCenter },
    'top-right': { top: top, left: tbVerRight },

    'left-top': { top: top, left: lrHorLeft },
    'left-center': { top: verCenter, left: lrHorLeft },
    'left-bottom': { top: bottom, left: lrHorLeft },

    'right-top': { top: top, left: lrHorRight },
    'right-center': { top: verCenter, left: lrHorRight },
    'right-bottom': { top: bottom, left: lrHorRight }
  };

  return function (prop) {
    return position[prop] || position['bottom-left'];
  };
};

exports.default = {
  dim: dim,
  pos: pos,
  offset: offset
};